@@ -4,7 +4,12 @@ import smtplib, ssl
 import random, string, uuid
 import base64
 class login:
-    k=str(uuid.getnode())
+    ak=str(uuid.getnode())
+    ake=k.encode('utf-8')
+    aey=hashlib.sha256(ke)
+    global key
+    akey=ey.hexdigest()
+    k=akey
     ke=k.encode('utf-8')
     ey=hashlib.md5(ke)
     global key
@@ -25,7 +30,7 @@ class login:
             print('Please Enter auth_id')
             sys.exit()
         else:
-            global auth_id
+            #global auth_id
             global r
             r=requests.get('https://pastebin.com/raw/'+auth_id)
     def verify(mail, username, password):
@@ -51,7 +56,7 @@ class login:
             print('Invalid Username Password Or Mail!')
             sys.exit()
 class verify:
-    def verify(mail, subject, mail_text):
+    def verify(auth_id, mail, subject, mail_text):
         global code
         login=requests.get('https://pastebin.com/'+auth_id)
         email=mail.encode('utf-8')
